@@ -9,35 +9,44 @@ configure and implement a workflow to operate on a signac_ data space.
 .. _signac: https://signac.io/
 """
 from . import environment, errors, scheduling, testing
+from .aggregates import aggregator, get_aggregate_id
 from .environment import get_environment
 from .operations import cmd, directives, with_job
 from .project import FlowProject, IgnoreConditions, classlabel, label, staticlabel
 from .template import init
 
 # Import packaged environments unless disabled in config:
-from .util.config import get_config_value
+from .util.config import _FLOW_CONFIG_DEFAULTS
+from .util.config import get_config_value as _get_config_value
 from .util.misc import redirect_log
 from .version import __version__
 
-if get_config_value("import_packaged_environments", default=True):
-    from . import environments  # noqa: F401
-
-
 __all__ = [
     "environment",
     "errors",
     "scheduling",
     "testing",
-    "IgnoreConditions",
-    "FlowProject",
-    "label",
-    "classlabel",
-    "staticlabel",
+    "aggregator",
+    "get_aggregate_id",
+    "get_environment",
     "cmd",
     "directives",
-    "get_environment",
+    "with_job",
+    "FlowProject",
+    "IgnoreConditions",
+    "classlabel",
+    "label",
+    "staticlabel",
     "init",
     "redirect_log",
-    "with_job",
     "__version__",
 ]
+
+
+if _get_config_value(
+    "import_packaged_environments",
+    default=_FLOW_CONFIG_DEFAULTS["import_packaged_environments"],
+):
+    from . import environments  # noqa: F401
+
+    __all__.append("environments")
